""" wenxin global variables """
import os
from wenxin_api.const import SOURCE_WENXIN, SOURCE_CONSOLE
# http request
TIMEOUT_SECS = 600
MAX_CONNECTION_RETRIES = 2
REQUEST_SLEEP_TIME = 20
ACCESS_TOKEN_URL = "https://wenxin.baidu.com/moduleApi/portal/api/oauth/token"
ACCESS_TOKEN_URL_CONSOLE = "https://aip.baidubce.com/oauth/2.0/token"

API_REQUEST_URLS = ["https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/1.0/tuning", # 0
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.21/zeus", # 1
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.22/zeus", # 2
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.23/zeus", # 3
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.24/zeus", # 4
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.25/zeus", # 5 
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.26/zeus", # 6
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.27/zeus", # 7
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.28/zeus", # 8
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/1.0/tuning-train", # 9
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/1.0/tuning-inference"] # 10

VILG_CREATE_URL = "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernievilg/v1/txt2img"
VILG_RETRIEVE_URL = "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernievilg/v1/getImg"

VILG_CREATE_URL_CONSOLE = "https://aip.baidubce.com/rpc/2.0/ernievilg/v1/txt2img"
VILG_RETRIEVE_URL_CONSOLE = "https://aip.baidubce.com/rpc/2.0/ernievilg/v1/getImg"

SOURCE = SOURCE_WENXIN


ak = os.environ.get("WENXINAPI_AK", None)
sk = os.environ.get("WENXINAPI_SK", None)
access_token = os.environ.get("WENXINAPI_ACCESS_TOKEN", None)
debug = False
proxy = None



""" composition """
from wenxin_api.api import Task
from wenxin_api.error import IllegalRequestArgumentError
from wenxin_api import log
logger = log.get_logger()

class Composition(Task):
    """ composition task """
    @staticmethod
    def _resolve_result(resp):
        rst = {}
        rst["result"] = resp["result"]
        return rst

    @classmethod
    def create(cls, text=None, model=None, **params):
        """ create """
        if text is None:
            raise IllegalRequestArgumentError("text shouldn't be none")
        model_id = 1 if model is None else model.id
        # params["seq_len"] = params.get("seq_len", 512)
        # params["topp"] = params.get("topp", 0.9)
        # params["penalty_score"] = params.get("penalty_score", 1.2)
        # params["min_dec_len"] = params.get("min_dec_len", 128)
        # params["is_unidirectional"] = params.get("is_unidirectional", 0)
        # params["task_prompt"] = params.get("task_prompt", "zuowen")
        # params["text"] = "作文题目：{} 正文：".format(params["text"])
        params["api_type"] = params.get("api_type", 1)
        logger.info("model {}: starts writing".format(model_id))
        resp = cls.default_request(text=text, **params)
        return cls._resolve_result(resp)